@@ -49,7 +49,7 @@ _wnck_get_cardinal (Window  xwindow,
 			       atom,
 			       0, G_MAXLONG,
 			       False, XA_CARDINAL, &type, &format, &nitems,
-			       &bytes_after, (guchar **)&num);  
+			       &bytes_after, (void*)&num);  
   err = _wnck_error_trap_pop ();
   if (err != Success ||
       result != Success)
@@ -90,7 +90,7 @@ _wnck_get_wm_state (Window  xwindow)
 			       wm_state,
 			       0, G_MAXLONG,
 			       False, wm_state, &type, &format, &nitems,
-			       &bytes_after, (guchar **)&num);  
+			       &bytes_after, (void*)&num);
   err = _wnck_error_trap_pop ();
   if (err != Success ||
       result != Success)
@@ -130,7 +130,7 @@ _wnck_get_window (Window  xwindow,
 			       atom,
 			       0, G_MAXLONG,
 			       False, XA_WINDOW, &type, &format, &nitems,
-			       &bytes_after, (guchar **)&w);  
+			       &bytes_after, (void*)&w);  
   err = _wnck_error_trap_pop ();
   if (err != Success ||
       result != Success)
@@ -170,7 +170,7 @@ _wnck_get_pixmap (Window  xwindow,
 			       atom,
 			       0, G_MAXLONG,
 			       False, XA_PIXMAP, &type, &format, &nitems,
-			       &bytes_after, (guchar **)&w);  
+			       &bytes_after, (void*)&w);  
   err = _wnck_error_trap_pop ();
   if (err != Success ||
       result != Success)
@@ -210,7 +210,7 @@ _wnck_get_atom (Window  xwindow,
 			       atom,
 			       0, G_MAXLONG,
 			       False, XA_ATOM, &type, &format, &nitems,
-			       &bytes_after, (guchar **)&a);  
+			       &bytes_after, (void*)&a);  
   err = _wnck_error_trap_pop ();
   if (err != Success ||
       result != Success)
@@ -285,7 +285,7 @@ _wnck_get_text_property (Window  xwindow,
   return retval;
 }
 
-char*
+static char*
 _wnck_get_string_property_latin1 (Window  xwindow,
                                   Atom    atom)
 {
@@ -401,7 +401,7 @@ _wnck_get_window_list (Window   xwindow,
 			       atom,
 			       0, G_MAXLONG,
 			       False, XA_WINDOW, &type, &format, &nitems,
-			       &bytes_after, (guchar **)&data);  
+			       &bytes_after, (void*)&data);  
   err = _wnck_error_trap_pop ();
   if (err != Success ||
       result != Success)
@@ -445,7 +445,7 @@ _wnck_get_atom_list (Window   xwindow,
 			       atom,
 			       0, G_MAXLONG,
 			       False, XA_ATOM, &type, &format, &nitems,
-			       &bytes_after, (guchar **)&data);  
+			       &bytes_after, (void*)&data);
   err = _wnck_error_trap_pop ();
   if (err != Success ||
       result != Success)
@@ -489,7 +489,7 @@ _wnck_get_cardinal_list (Window   xwindow,
 			       atom,
 			       0, G_MAXLONG,
 			       False, XA_CARDINAL, &type, &format, &nitems,
-			       &bytes_after, (guchar **)&nums);  
+			       &bytes_after, (void*)&nums);  
   err = _wnck_error_trap_pop ();
   if (err != Success ||
       result != Success)
@@ -522,8 +522,8 @@ _wnck_get_utf8_list (Window   xwindow,
   int err, result;
   Atom utf8_string;
   char **retval;
-  int i;
-  int n_strings;
+  guint i;
+  guint n_strings;
   char *p;
   
   utf8_string = _wnck_atom_get ("UTF8_STRING");
@@ -537,7 +537,7 @@ _wnck_get_utf8_list (Window   xwindow,
 			       0, G_MAXLONG,
 			       False, utf8_string,
 			       &type, &format, &nitems,
-			       &bytes_after, (guchar **)&val);  
+			       &bytes_after, (void*)&val);  
   err = _wnck_error_trap_pop ();
 
   if (err != Success ||
@@ -844,6 +844,8 @@ _wnck_close (Screen *screen,
   xev.xclient.data.l[0] = timestamp;
   xev.xclient.data.l[1] = 0;
   xev.xclient.data.l[2] = 0;
+  xev.xclient.data.l[3] = 0;
+  xev.xclient.data.l[4] = 0;
 
   XSendEvent (gdk_display,
               RootWindowOfScreen (screen),
@@ -881,6 +883,7 @@ _wnck_keyboard_move (Screen *screen,
   xev.xclient.data.l[1] = 0; /* unused */
   xev.xclient.data.l[2] = _NET_WM_MOVERESIZE_MOVE_KEYBOARD;
   xev.xclient.data.l[3] = 0; /* unused */
+  xev.xclient.data.l[4] = 0;
 
   XSendEvent (gdk_display,
               RootWindowOfScreen (screen),
@@ -906,6 +909,7 @@ _wnck_keyboard_size (Screen *screen,
   xev.xclient.data.l[1] = 0; /* unused */
   xev.xclient.data.l[2] = _NET_WM_MOVERESIZE_SIZE_KEYBOARD;
   xev.xclient.data.l[3] = 0; /* unused */
+  xev.xclient.data.l[4] = 0;
 
   XSendEvent (gdk_display,
               RootWindowOfScreen (screen),
@@ -937,6 +941,8 @@ _wnck_change_state (Screen  *screen,
   xev.xclient.data.l[0] = add ? _NET_WM_STATE_ADD : _NET_WM_STATE_REMOVE;
   xev.xclient.data.l[1] = state1;
   xev.xclient.data.l[2] = state2;
+  xev.xclient.data.l[3] = 0;
+  xev.xclient.data.l[4] = 0;
 
   XSendEvent (gdk_display,
 	      RootWindowOfScreen (screen),
@@ -962,6 +968,8 @@ _wnck_change_workspace (Screen     *screen,
   xev.xclient.data.l[0] = new_space;
   xev.xclient.data.l[1] = 0;
   xev.xclient.data.l[2] = 0;
+  xev.xclient.data.l[3] = 0;
+  xev.xclient.data.l[4] = 0;
 
   XSendEvent (gdk_display,
 	      RootWindowOfScreen (screen),
@@ -1045,6 +1053,8 @@ _wnck_change_viewport (Screen *screen,
   xev.xclient.data.l[0] = x;
   xev.xclient.data.l[1] = y;
   xev.xclient.data.l[2] = 0;
+  xev.xclient.data.l[3] = 0;
+  xev.xclient.data.l[4] = 0;
 
   XSendEvent (gdk_display,
 	      RootWindowOfScreen (screen),
@@ -1069,6 +1079,8 @@ _wnck_toggle_showing_desktop (Screen  *screen,
   xev.xclient.data.l[0] = show != FALSE;
   xev.xclient.data.l[1] = 0;
   xev.xclient.data.l[2] = 0;
+  xev.xclient.data.l[3] = 0;
+  xev.xclient.data.l[4] = 0;
 
   XSendEvent (DisplayOfScreen (screen),
 	      RootWindowOfScreen (screen),
@@ -1077,28 +1089,6 @@ _wnck_toggle_showing_desktop (Screen  *screen,
 	      &xev);
 }
 
-Window
-_wnck_get_group_leader (Window xwindow)
-{
-  XWMHints *hints;
-  Window ret;
-  
-  _wnck_error_trap_push ();
-  hints = XGetWMHints (gdk_display, xwindow);
-  _wnck_error_trap_pop ();
-
-  /* default to window being its own leader */
-  ret = xwindow;
-  
-  if (hints &&
-      (hints->flags & WindowGroupHint))
-    ret = hints->window_group;
-
-  XFree (hints);
-
-  return ret;
-}
-
 char*
 _wnck_get_session_id (Window xwindow)
 {
@@ -1442,7 +1432,7 @@ read_rgb_icon (Window         xwindow,
 			       _wnck_atom_get ("_NET_WM_ICON"),
 			       0, G_MAXLONG,
 			       False, XA_CARDINAL, &type, &format, &nitems,
-			       &bytes_after, ((guchar **)&data));
+			       &bytes_after, (void*)&data);
   
   err = _wnck_error_trap_pop ();
   
@@ -1749,7 +1739,7 @@ get_kwm_win_icon (Window  xwindow,
 			       False,
 			       _wnck_atom_get ("KWM_WIN_ICON"),
 			       &type, &format, &nitems,
-			       &bytes_after, (guchar **)&icons);  
+			       &bytes_after, (void*)&icons);  
 
   err = _wnck_error_trap_pop ();
   if (err != Success ||
@@ -2153,10 +2143,6 @@ _wnck_read_icons (Window         xwindow,
   return FALSE;
 }
 
-#ifdef HAVE_GDK_PIXBUF_NEW_FROM_STREAM
-#define gdk_pixbuf_new_from_inline gdk_pixbuf_new_from_stream
-#endif
-
 static GdkPixbuf*
 default_icon_at_size (int width,
                       int height)
